==> deepin-ocr_6.5.0.tar.xz: BUILD/translations/deepin-ocr_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainWidget</name>
    <message>
        <source>Recognizing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No text recognized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as TXT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recognize language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Simplified Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo (Ctrl+Shift+Z)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>OCR Tool</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-ocr_6.5.12.tar.xz: BUILD/translations/deepin-ocr_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainWidget</name>
    <message>
        <source>Recognizing</source>
        <translation>Genkognisering</translation>
    </message>
    <message>
        <source>Copied</source>
        <translation>Kopieret</translation>
    </message>
    <message>
        <source>No text recognized</source>
        <translation>Ingen tekst genkendt</translation>
    </message>
    <message>
        <source>Copy text</source>
        <translation>Kopier tekst</translation>
    </message>
    <message>
        <source>Save as TXT</source>
        <translation>Gem som TXT</translation>
    </message>
    <message>
        <source>Recognize language</source>
        <translation>Genkend sprog</translation>
    </message>
    <message>
        <source>Simplified Chinese</source>
        <translation>Forenklet kinesisk</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Engelsk</translation>
    </message>
    <message>
        <source>Traditional Chinese</source>
        <translation>Traditionelt kinesisk</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Fortryd (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Redo (Ctrl+Shift+Z)</source>
        <translation>Gentag (Ctrl+Shift+Z)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>OCR Tool</source>
        <translation>OCR-Værktøj</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klip</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Indsæt</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Vælg alt</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>Tip: Jo bedre billedet er, jo mere præcis er teksten</translation>
    </message>
</context>
</TS>
